==> eiffelstudio-16.05.tar: F_code/C18/pr877.c <==
/*
 * Code for class PRECOMP_INFO
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "pr877.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {PRECOMP_INFO}.make */
void F1619_15565 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_7_);
	F1544_14668(Current, ti4_1);
	{
		/* INLINED CODE (start) */
		ti4_1 = F1543_14711(RTCW(arg1), ((EIF_INTEGER_32) -1L));
		*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_2_) = (EIF_INTEGER_32) ti4_1;
		/* END INLINED CODE */
	}
	;
	for (;;) {
		{
			/* INLINED CODE (after) */
			tb1 = (EIF_BOOLEAN)  0;
			tb1 = F1543_14748(RTCW(arg1), *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_2_));
			/* END INLINED CODE */
		}
		tb1 = tb1;
		if (tb1) break;
		{
			/* INLINED CODE (key_for_iteration) */
			ti4_1 = (EIF_INTEGER_32)  0;
			tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
			ti4_1 = 
				/* INLINED CODE (SPECIAL.item) */
				*((EIF_INTEGER_32 *)RTCW(tr1) + (*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_2_)))
				/* END INLINED CODE */;
			/* END INLINED CODE */
		}
		ti4_1 = ti4_1;
		tr1 = F1543_14678(RTCW(arg1));
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
		F1544_14714(Current, ti4_1, tr1);
		{
			/* INLINED CODE (forth) */
			ti4_1 = F1543_14711(RTCW(arg1), *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_2_));
			*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_2_) = (EIF_INTEGER_32) ti4_1;
			/* END INLINED CODE */
		}
		;
	}
	tr1 = RTOSCF(15525,F1617_15525,(Current));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) tr1;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCV(RTOSCF(8960,F903_8960,(Current)))+ _LNGOFF_110_54_0_3_);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_7_3_0_9_) = (EIF_INTEGER_32) ti4_1;
	tr1 = *(EIF_REFERENCE *)(RTCV(RTOSCF(8960,F903_8960,(Current))) + _REFACS_63_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {PRECOMP_INFO}.compiler_version */
EIF_REFERENCE F1619_15567 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


/* {PRECOMP_INFO}.name */
EIF_REFERENCE F1619_15568 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


void EIF_Minit877 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C18/pr877.c <==
/*
 * Code for class PRECOMP_INFO
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "pr877.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {PRECOMP_INFO}.make */
void F1656_15842 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_7_);
	F1584_15224(Current, ti4_1);
	{
		/* INLINED CODE (HASH_TABLE.start) */
		ti4_1 = F1583_15268(RTCW(arg1), ((EIF_INTEGER_32) -1L));
		*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_2_) = (EIF_INTEGER_32) ti4_1;
		/* END INLINED CODE */
	}
	;
	for (;;) {
		{
			/* INLINED CODE (HASH_TABLE.after) */
			tb1 = (EIF_BOOLEAN)  0;
			tb1 = F1583_15305(RTCW(arg1), *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_2_));
			/* END INLINED CODE */
		}
		tb1 = tb1;
		if (tb1) break;
		{
			/* INLINED CODE (HASH_TABLE.key_for_iteration) */
			ti4_1 = (EIF_INTEGER_32)  0;
			tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
			ti4_1 = 
				/* INLINED CODE (SPECIAL.item) */
				*((EIF_INTEGER_32 *)RTCW(tr1) + (*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_2_)))
				/* END INLINED CODE */;
			/* END INLINED CODE */
		}
		ti4_1 = ti4_1;
		{
			/* INLINED CODE (HASH_TABLE.item_for_iteration) */
			tr1 = (EIF_REFERENCE)  0;
			tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
			tr1 = 
				/* INLINED CODE (SPECIAL.item) */
				*((EIF_REFERENCE *)RTCW(tr1) + (*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_2_)))
				/* END INLINED CODE */;
			/* END INLINED CODE */
		}
		tr1 = tr1;
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
		F1584_15271(Current, ti4_1, tr1);
		{
			/* INLINED CODE (HASH_TABLE.forth) */
			ti4_1 = F1583_15268(RTCW(arg1), *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_2_));
			*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_6_3_0_2_) = (EIF_INTEGER_32) ti4_1;
			/* END INLINED CODE */
		}
		;
	}
	tr1 = RTOSCF(15837,F1655_15837, (Current));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) tr1;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCV(RTOSCF(8258,F616_8258, (Current)))+ _LNGOFF_109_57_0_3_);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_7_3_0_9_) = (EIF_INTEGER_32) ti4_1;
	tr1 = *(EIF_REFERENCE *)(RTCV(RTOSCF(8258,F616_8258, (Current))) + _REFACS_62_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
	RTLE;
}

void EIF_Minit877 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
